Enum shiplift::transport::Transport [−][src]
pub enum Transport {
Tcp {
client: Client<HttpConnector>,
host: String,
},
EncryptedTcp {
client: Client<HttpsConnector<HttpConnector>>,
host: String,
},
Unix {
client: Client<UnixConnector>,
path: String,
},
}Transports are types which define the means of communication with the docker daemon
Variants
A network tcp interface
Show fields
Fields of Tcp
client: Client<HttpConnector>host: StringTCP/TLS
Show fields
Fields of EncryptedTcp
client: Client<HttpsConnector<HttpConnector>>host: StringA Unix domain socket
Show fields
Fields of Unix
client: Client<UnixConnector>path: StringImplementations
impl Transport[src]
impl Transport[src]pub async fn request<B, H>(
&self,
method: Method,
endpoint: impl AsRef<str>,
body: Option<(B, Mime)>,
headers: Option<H>
) -> Result<String> where
B: Into<Body>,
H: IntoIterator<Item = (&'static str, String)>, [src]
&self,
method: Method,
endpoint: impl AsRef<str>,
body: Option<(B, Mime)>,
headers: Option<H>
) -> Result<String> where
B: Into<Body>,
H: IntoIterator<Item = (&'static str, String)>,
Make a request and return the whole response in a String
pub fn stream_chunks<'stream, H, B>(
&'stream self,
method: Method,
endpoint: impl AsRef<str> + 'stream,
body: Option<(B, Mime)>,
headers: Option<H>
) -> impl Stream<Item = Result<Bytes>> + 'stream where
B: Into<Body> + 'stream,
H: IntoIterator<Item = (&'static str, String)> + 'stream, [src]
&'stream self,
method: Method,
endpoint: impl AsRef<str> + 'stream,
body: Option<(B, Mime)>,
headers: Option<H>
) -> impl Stream<Item = Result<Bytes>> + 'stream where
B: Into<Body> + 'stream,
H: IntoIterator<Item = (&'static str, String)> + 'stream,
pub async fn stream_upgrade<B>(
&self,
method: Method,
endpoint: impl AsRef<str>,
body: Option<(B, Mime)>
) -> Result<impl AsyncRead + AsyncWrite> where
B: Into<Body>, [src]
&self,
method: Method,
endpoint: impl AsRef<str>,
body: Option<(B, Mime)>
) -> Result<impl AsyncRead + AsyncWrite> where
B: Into<Body>,